@@ -44,6 +44,8 @@ private:
   Lum::OS::ColorRef      frameShadowColor;
 
 private:
+  void UpdateDimensions();
+
   size_t GetBoxSize() const;
   Lum::Images::Image* GetImage(Image image) const;
 
@@ -79,7 +81,6 @@ public:
 
   void CalcSize();
 
-  void Layout();
   void Draw(int x, int y, size_t w, size_t h);
 
   bool HandleMouseEvent(const Lum::OS::MouseEvent& event);
