@@ -422,6 +422,7 @@ public:
 
     label->AddLabel(L"Level:",horiz2);
 
+    /*
     textValue=new Lum::TextValue();
     textValue->SetFlex(true,false);
     textValue->SetMinWidth(Lum::Base::Size::stdCharWidth,5);
@@ -432,7 +433,7 @@ public:
     textValue->SetFlex(true,false);
     textValue->SetMinWidth(Lum::Base::Size::stdCharWidth,5);
     textValue->SetModel(pushes);
-    label->AddLabel(L"Pushes:",textValue);
+    label->AddLabel(L"Pushes:",textValue);*/
     label->AddLabel(L"Finished:",new Lum::LED(gameArea->GetFinishedModel()));
 
     vert->Add(label);
